<?php

/**
 * @file
 */

use Drupal\file\Entity\File;
use Drupal\Core\Render\BubbleableMetadata;
use Drupal\Core\Url;

/**
 * Implements hook_token_info().
 */
function og_default_image_token_info() {
  $type = [
    'name' => t('OG default image'),
    'description' => t('Token for OG default image'),
  ];

  $token['og_default_image'] = [
    'name' => t("Default OG image"),
    'description' => t('Image url of OG default image'),
  ];

  return [
    'types' => ['og_default_image' => $type],
    'tokens' => ['og_default_image' => $token],
  ];
}

/**
 * Implements hook_tokens().
 */
function og_default_image_tokens($type, $tokens, array $data, array $options, BubbleableMetadata $bubbleable_metadata) {

  $replacements = [];

  if ($type == 'og_default_image') {
    foreach ($tokens as $name => $original) {
      switch ($name) {
        case 'og_default_image':
          if (function_exists('get_og_default_image_path')) {
            $replacements[$original] = get_og_default_image_path();
          }
      }
    }
  }
  // Return the replacements.
  return $replacements;
}

/**
 *
 */
function get_og_default_image_path() {

  $config = \Drupal::config('og_default_image.settings');
  $fid = $config->get('og_default_image');

  if (!$fid) {
    return 'Please upload an image';
  }

  $file = File::load($fid[0]);
  if ($file) {
    $file_uri = $file->getFileUri();
    $file_path = Url::fromUri(\Drupal::service('file_url_generator')->generateAbsoluteString($file_uri));

    return $file_path->getUri();
  }

}
